@@ -22,7 +22,7 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: data.c 1685 2010-05-10 00:16:38Z beerli $
+$Id: data.c 1694 2010-05-25 01:55:58Z beerli $
 
 -----------------------------------
 add this to the microsatellite data, this will allow to use
@@ -755,7 +755,6 @@ read_sites (data_fmt * data, world_fmt *world)
     long zz=0; //zz is used for mutationmodels and is not reset at closing ')'
     input = (char *) mycalloc(LONGLINESIZE ,sizeof(char));
     word = (char *) mycalloc(LONGLINESIZE ,sizeof(char));
-    
     for (locus = 0; locus < data->loci; locus++)
     {
       read_word(data->infile, input);
@@ -1381,11 +1380,13 @@ read_hapmap (FILE * infile, data_fmt * data, option_fmt * options,
 	    fprintf(stdout, " freq[%c]=%f freq[%c]=%f\n",label1,
 		    (float) label1count/label12count,label2, (float) label2count/label12count);
 	  }
-	data->numind[pop][locus] = label12count;
+	//was messing with the reading, use fraction data->numind[pop][locus] = label12count;
 	//if(options->randomsubset > 0 && options->randomsubset < data->numind[pop][locus])
 	//  data->numalleles[pop][locus] = options->randomsubset * genomes;
 	//else
-	  data->numalleles[pop][locus] = data->numind[pop][locus] * genomes;
+	data->numalleles[pop][locus] = data->numind[pop][locus] * genomes;
+	label1count = lround(label1count/label12count * data->numalleles[pop][locus]);
+	label12count = data->numalleles[pop][locus] - label1count;
 	for(ind=0;ind < label1count; ind++)
 	  {
 	    data->yy[pop][ind][locus][0][0] = label1;
