@@ -24,7 +24,7 @@ Copyright 2003-2005 Peter Beerli, Tallahassee FL
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: laguerre.c 356 2006-05-17 18:22:36Z beerli $
+$Id: laguerre.c 1607 2010-02-05 19:49:48Z beerli $
 */
 /* \file laguerre.c
 Calculates the Laguerre Quadrature points, used for gamma deviated site rate variation
@@ -450,13 +450,13 @@ integrate_laguerre (long categs, MYREAL *rate,
     long i;
     MYREAL *temp;
     int *stemp;
-    *rmax = -DBL_MAX;
+    *rmax = -MYREAL_MAX;
 
     temp = (MYREAL *) mycalloc (categs, sizeof (MYREAL));
     stemp = (int *) mycalloc (categs, sizeof (int));
     for (i = 0; i < categs; i++)
     {
-        temp[i] = (*func) (rate[i], (void *) helper);
+        temp[i] = (*func) (rate[i], /*(void *)*/ helper);
         stemp[i] = (int) helper->sign;
         if (temp[i] > *rmax)
             *rmax = temp[i];
